<?php

use CKPL\Pay\Storage\AbstractStorage;

/**
 * Class PS_Gateway_Conotoxia_Pay_Storage
 */
class PS_Gateway_Conotoxia_Pay_Storage extends AbstractStorage
{
    /**
     * PS_Gateway_Conotoxia_Pay_Storage constructor.
     */
    public function __construct()
    {
        $this->items = [];

        $this->load();
    }

    /**
     * @param string $key
     *
     * @return bool
     */
    public function hasItem(string $key): bool
    {
        return \array_key_exists($key, $this->items);
    }

    /**
     * @param string $key
     * @param mixed  $value
     *
     * @return void
     */
    public function setItem(string $key, $value): void
    {
        if ($key === static::TOKEN || $key === static::PAYMENT_SERVICE_PUBLIC_KEYS) {
            Configuration::updateValue('conotoxia-pay-'.$key,
                \json_encode($value,
                    JSON_PRESERVE_ZERO_FRACTION | JSON_UNESCAPED_SLASHES));
            $this->items[$key] = $value;
        } else {
            Configuration::updateValue('conotoxia-pay-'.$key, $value);
            $this->items[$key] = (string)$value;
        }
    }

    /**
     * @return void
     */
    protected function load(): void
    {
        $arrayItems = [static::TOKEN, static::PAYMENT_SERVICE_PUBLIC_KEYS];
        $stringItems = [static::PUBLIC_KEY_ID, static::PUBLIC_KEY_CHECKSUM];
        foreach ($arrayItems as $arrayItem) {
            if ( ! empty(Configuration::get('conotoxia-pay-'.$arrayItem))) {
                $this->items[$arrayItem]
                    = \json_decode(Configuration::get('conotoxia-pay-'
                    .$arrayItem), true);
            }
        }

        foreach ($stringItems as $stringItem) {
            if ( ! empty(Configuration::get('conotoxia-pay-'.$stringItem))) {
                $this->items[$stringItem] = Configuration::get('conotoxia-pay-'
                    .$stringItem);
            }
        }
    }

    /**
     * @return void
     */
    public function clear(): void
    {
        Configuration::updateValue('conotoxia-pay-' . StorageInterface::TOKEN, '');
        Configuration::updateValue('conotoxia-pay-' . StorageInterface::PUBLIC_KEY_CHECKSUM, '');
        Configuration::updateValue('conotoxia-pay-' . StorageInterface::PAYMENT_SERVICE_PUBLIC_KEYS, '');
        Configuration::updateValue('conotoxia-pay-' . StorageInterface::PUBLIC_KEY_ID, '');
    }
}
